@@ -2,9 +2,14 @@ from abc import abstractmethod
 from data2code_sdk.plugin.interface_plugin import IPlugin
 from typing import List
 from data2code_sdk.plugin.raw_data import RawData
+from data2code_sdk.plugin.plugin_type import PluginType
 
 
 class ILoaderPlugin(IPlugin):
+    @staticmethod
+    def get_plugin_type():
+        return PluginType.LOADER
+
     @abstractmethod
     def process(self, path: chr, results: List[RawData]):
         """
